@@ -1,39 +1,37 @@
 #!/usr/bin/env python3
 # -*- coding: UTF-8 -*-
 
+"""Some checks on files or directories."""
 from os.path import *
 from os import makedirs
-from user_tools.util_file import get_file_size
 
 
 def is_exist(file_path, create=False):
     """Returns whether file_path exists,
-    If create is True, create file_path if it does not exist."""
+    If create is True, create a directory named file_path if it does not exist.
+    """
 
     if create and not exists(file_path):
-        if file_or_dir(file_path) == "dir":
-            makedirs(file_path)
-        elif file_or_dir(file_path) == "file":
-            with open(file_path, "a+", encoding="UTF-8") as f:
-                f.write("")
+        makedirs(file_path)
     return exists(file_path)
 
 
 def is_not_null(file_path):
-    """Test whether file_path is null.
-    Return True if file_path not null."""
+    """Test whether file_path is null,
+    Return True if file_path exist and not null."""
 
     result = False
     if is_exist(file_path):
-        result = get_file_size(file_path) != 0
+        result = getsize(file_path) != 0
     return result
 
 
 def file_or_dir(file_path):
     """ Returns the file_path file type.\n
     Directories return dir,\n
-    files return file,\n
-    others return None."""
+    Files return file,\n
+    Others return empty string.\n
+    If file_path does not exist return empty string."""
 
     result = ""
     if isdir(file_path):
